%define anolis_release 1

%global libqat_soversion  3
%global libusdm_soversion 0
%define abidir %{_prefix}/lib/compatibility/%{name}

Name:             qatlib
Version:          23.02.0
Release:          %{anolis_release}%{?dist}
Summary:          Intel QuickAssist user space library
# The entire source code is released under BSD.
# For a breakdown of inbound licenses see the INSTALL file.
License:          BSD and (BSD or GPLv2)
URL:              https://github.com/intel/%{name}
Source0:          https://github.com/intel/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:    gcc make autoconf automake libtool
BuildRequires:    systemd
BuildRequires:    openssl-devel zlib-devel systemd-devel 
BuildRequires:    yasm nasm
BuildRequires:	  abi-dumper
Requires(pre):    shadow-utils
Recommends:       qatlib-service

ExclusiveArch:  x86_64

%description
The QATlib is a software library that provides a high-level interface to
the Intel QuickAssist Technology (QAT) hardware accelerator. It is designed
to help developers easily integrate QAT acceleration into their applications
without having to deal with the low-level details of the QAT technology.

The QATlib provides a set of APIs and drivers that allow developers to
access the QAT hardware acceleration from their applications. These APIs
abstract the hardware details of the QAT accelerator, making it easier for
developers to take advantage of the acceleration without having to deal with
low-level details.

The QATlib supports a wide range of cryptographic algorithms and compression
formats, including AES, SHA-256, RSA, and LZS. It also supports a variety
of programming languages, including C/C++, Java, and Python.

The QATlib is designed to be highly flexible, allowing developers to choose
the level of acceleration that is appropriate for their specific use case.
For example, developers can choose to offload only a portion of their
cryptographic or compression workload to the QAT accelerator, or they can
choose to offload the entire workload.

Overall, the QATlib is a powerful and flexible software library that can
help developers easily integrate QAT acceleration into their applications,
providing a significant boost in performance and reduced latency.

%package       devel
Summary:       Headers and libraries to build applications that use qatlib
Requires:      %{name} = %{version}-%{release}

%description   devel
This package contains headers and libraries required to build applications
that use the Intel QuickAssist APIs.

%package       tests
Summary:       Sample applications that use qatlib
Requires:      %{name} = %{version}-%{release}

%description   tests
This package contains sample applications that use the Intel QuickAssists APIs.

%package       service
Summary:       A daemon for qatlib resources management
Requires:      %{name} = %{version}-%{release}
%{?systemd_requires}

%description   service
This package contains a daemon that manages QAT resources for the Intel
QuickAssist Technology user space library (qatlib).

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1

%build
autoreconf -vif
%configure
%make_build

%install
%make_install
make DESTDIR=%{buildroot} samples-install

mkdir -p %{buildroot}/%{abidir}
pushd %{buildroot}/%{abidir}
for full_name in $(find %{buildroot} -name "*.so*") ; do
        f=`echo ${full_name##*/}`
        (file $full_name | grep "shared object" > /dev/null 2>&1 && abi-dumper $full_name -o $f.dump > /dev/null 2>&1) || echo "ok"
done
popd

find %{buildroot}%{_libdir} -iname '*.a' -exec rm -rf {} \;
find %{buildroot}%{_libdir} -iname '*.la' -exec rm -rf {} \;

%generate_compatibility_deps

%pre
getent group qat >/dev/null || groupadd -r qat
exit 0

%post          service
%systemd_post qat.service

%preun         service
%systemd_preun qat.service

%postun        service
%systemd_postun_with_restart qat.service

%files
%dir %{abidir}
%license LICENSE*
%dir %{abidir}
%{_libdir}/libqat.so.%{libqat_soversion}*
%{_libdir}/libusdm.so.%{libusdm_soversion}*
%{abidir}/*.dump
%{abidir}/*.list

%files         devel
%{_libdir}/libqat.so
%{_libdir}/libusdm.so
%{_includedir}/qat
%{_libdir}/pkgconfig/*.pc

%files         tests
%doc quickassist/lookaside/access_layer/src/sample_code/README.txt
%attr(0754,-,qat) %{_bindir}/cpa_sample_code
%attr(0754,-,qat) %{_bindir}/dc_dp_sample
%attr(0754,-,qat) %{_bindir}/dc_stateless_sample
%attr(0754,-,qat) %{_bindir}/dc_stateless_multi_op_sample
%attr(0754,-,qat) %{_bindir}/algchaining_sample
%attr(0754,-,qat) %{_bindir}/ccm_sample
%attr(0754,-,qat) %{_bindir}/cipher_sample
%attr(0754,-,qat) %{_bindir}/gcm_sample
%attr(0754,-,qat) %{_bindir}/hash_file_sample
%attr(0754,-,qat) %{_bindir}/hash_sample
%attr(0754,-,qat) %{_bindir}/ipsec_sample
%attr(0754,-,qat) %{_bindir}/ssl_sample
%attr(0754,-,qat) %{_bindir}/sym_dp_sample
%attr(0754,-,qat) %{_bindir}/dh_sample
%attr(0754,-,qat) %{_bindir}/eddsa_sample
%attr(0754,-,qat) %{_bindir}/prime_sample
%attr(0754,-,qat) %{_bindir}/hkdf_sample
%attr(0754,-,qat) %{_bindir}/ec_montedwds_sample
%{_datadir}/qat/calgary
%{_datadir}/qat/calgary32
%{_datadir}/qat/canterbury

%files         service
%{_sbindir}/qatmgr
%{_sbindir}/qat_init.sh
%{_unitdir}/qat.service
%{_mandir}/man8/qatmgr.8*
%{_mandir}/man8/qat_init.sh.8*

%files         doc
%doc INSTALL README.md

%changelog
* Mon Apr 10 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 23.02.0-1
- Update to version 23.02

* Thu Oct 13 2022 happy_orange <songnannan@linux.alibaba.com> - 22.07.0-1
- Init package from upstream
